Skip to contents

Imports data from the data flow D data viewer. This is useful for binding onto datasets obtained using get_eea_parquet_files() to assign monitoring data with relevant site information. The user must select a subset of countries using the countries argument.

Usage

import_eea_stations(countries = NULL)

Arguments

countries

A vector of country codes from import_eea_countries(). If NULL, data from all countries will be imported.

Author

Jack Davison