Conveniently import European Air Quality CAMS data into R
Source:R/import_eea_raster.R
import_eea_raster.RdThis function is a convenient way to use EEA AQ modelling data in an R
session. It calls get_eea_raster_files() to download the .tiff files into a
temporary directory and reads them into the R session using terra::rast().
Arguments
- country
A single country code from
import_eea_countries().- city
A single city in the given
countryfromimport_eea_cities(). IfNULL, data from all cities in the givencountrywill be imported.- pollutants
A vector of pollutant IDs from
import_eea_pollutants()(e.g.,"pm10").- datetime_start, datetime_end
Start and end date times, provided as
POSIXct,DateorintegerR objects. If anintegeris provided, this should represent the year of interest; fordatetime_startthis will be represent the first hour of the year and fordatetime_endit will represent the last hour of the year, meaning providing the same integer to each will return a year of data.- ...
Not currently used.
- .endpoint
Provided for consistency with
import_eea_monitoring(). Currently only"files"is supported, which usesget_eea_raster_files().
Value
a tibble